@@ -357,6 +357,37 @@ class ObjectIdentifierWithSchemaEncoderTestCase(BaseTestCase):
         ) == ints2octs((6, 6, 43, 6, 0, 191, 255, 126))
 
 
+class RelativeOIDEncoderTestCase(BaseTestCase):
+    def testOne(self):
+        assert encoder.encode(
+            univ.RelativeOID((39,))
+        ) == ints2octs((13, 1, 39))
+
+    def testTwo(self):
+        assert encoder.encode(
+            univ.RelativeOID((5, 6))
+        ) == ints2octs((13, 2, 5, 6))
+
+    def testThree(self):
+        assert encoder.encode(
+            univ.RelativeOID((5, 6, 7))
+        ) == ints2octs((13, 3, 5, 6, 7))
+
+    def testLarge(self):
+        assert encoder.encode(
+            univ.RelativeOID((1079, 18446744073709551535184467440737095))
+        ) == ints2octs((0x0D, 0x13, 0x88, 0x37, 0x83, 0xC6, 0xDF, 0xD4, 0xCC,
+                        0xB3, 0xFF, 0xFF, 0xFE, 0xF0, 0xB8, 0xD6, 0xB8, 0xCB,
+                        0xE2, 0xB6, 0x47))
+
+
+class RelativeOIDWithSchemaEncoderTestCase(BaseTestCase):
+    def testOne(self):
+        assert encoder.encode(
+            (5, 6, 7), asn1Spec=univ.RelativeOID()
+        ) == ints2octs((13, 3, 5, 6, 7))
+
+
 class RealEncoderTestCase(BaseTestCase):
     def testChar(self):
         assert encoder.encode(
